( cd opt/kde/share/doc/HTML/pt/kexi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kexi ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kivio ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/krita ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/krita ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kugar ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kword ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/koffice ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/koshell ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kspread ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/karbon ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/karbon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kchart ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kpresenter ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kplato ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kplato ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/thesaurus ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/pt/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/kformula ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
